# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PagedResultsModelHubResponse(Model):
    """PagedResultsModelHubResponse.

    :param result: Contains a list of paged items
    :type result: list[~smartdiagnostics_sdk.models.HubResponse]
    :param total: The total number of items returned from a query (not just
     those in the paged results list)
    :type total: int
    :param total_pages: The total number of pages of items that will be
     returned
    :type total_pages: int
    """

    _attribute_map = {
        'result': {'key': 'Result', 'type': '[HubResponse]'},
        'total': {'key': 'Total', 'type': 'int'},
        'total_pages': {'key': 'TotalPages', 'type': 'int'},
    }

    def __init__(self, *, result=None, total: int=None, total_pages: int=None, **kwargs) -> None:
        super(PagedResultsModelHubResponse, self).__init__(**kwargs)
        self.result = result
        self.total = total
        self.total_pages = total_pages



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonitoringPointTypeCodeModel(Model):
    """MonitoringPointTypeCodeModel.

    :param text:
    :type text: str
    :param value:
    :type value: int
    """

    _attribute_map = {
        'text': {'key': 'text', 'type': 'str'},
        'value': {'key': 'value', 'type': 'int'},
    }

    def __init__(self, *, text: str=None, value: int=None, **kwargs) -> None:
        super(MonitoringPointTypeCodeModel, self).__init__(**kwargs)
        self.text = text
        self.value = value
